@@ -6,7 +6,7 @@ use HTML::TableContent::Table::Caption;
 use HTML::TableContent::Table::Header;
 use HTML::TableContent::Table::Row;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 extends 'HTML::TableContent::Element';
 
@@ -47,7 +47,7 @@ sub aoa {
     }
 
     for ( $_[0]->all_rows ) {
-       my @row = map { $_->data->[0] } $_->all_cells;
+       my @row = $_->array;
        push @{ $aoa }, \@row; 
     }
     
@@ -57,8 +57,7 @@ sub aoa {
 sub aoh {
     my $aoh = [ ];
     for ($_[0]->all_rows) {
-        my $hash = { };
-        map { $hash->{$_->header->data->[0]} = $_->data->[0] } $_->all_cells;
+        my $hash = $_->hash;
         push @{ $aoh }, $hash;
     }
     return $aoh;
@@ -337,7 +336,7 @@ HTML::TableContent::Table - Base class for table's
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
